# enimie
it used for wordlist attacks

## Installation
```pip install enimie```

## License                                        
© 2020 Kavindu Nimesh
This repository is licensed under the MIT license. See LICENSE for details.
